@@ -2,6 +2,7 @@
 import datetime
 import logging
 import os
+import subprocess
 import sys
 
 import ncscli.batchRunner as batchRunner
@@ -18,11 +19,11 @@ class locustFrameProcessor(batchRunner.frameProcessor):
         #return 'worker_%03d_requests.csv' % frameNum
 
     def frameCmd( self, frameNum ):
-        usersPerWorker = 20  # number of simulated users per worker instance
-        rampUpRate = 5  # number of simulated users to spawn per second
-        duration = 60  # number of seconds to run the test
+        usersPerWorker = 6  # number of simulated users per worker instance
+        rampUpRate = 1  # number of simulated users to spawn per second (can be fractional)
+        duration = 60  # number of seconds to run the test (must be integer)
         csvSpec = '--csv ~/worker_%03d' % frameNum
-        cmd = 'cd locustWorker && python3 -u ./runLocustWorker.py --host=https://loadtest-target.neocortix.com %s --exit-code-on-error 0 --no-web -c %d -r %d --run-time %d' % (
+        cmd = 'cd locustWorker && python3 -u ./runLocustWorker.py --host=https://loadtest-target.neocortix.com %s --only-summary --exit-code-on-error 0 --no-web -c %d -r %f --run-time %d' % (
             csvSpec, usersPerWorker, rampUpRate, duration
         )
         return cmd
@@ -48,13 +49,19 @@ try:
         encryptFiles=False,
         timeLimit = 14*60,
         frameTimeLimit = 240,
-        filter = '{"dpr": ">=24"}',
+        filter = '{"dpr": ">=48","ram:":">=2800000000","app-version": ">=2.1.11"}',
         outDataDir = outDataDir,
         startFrame = 1,
         endFrame = 5,
         nWorkers = 6,
+        limitOneFramePerWorker = True,
         autoscaleMax = 2
     )
+    if os.path.isfile( outDataDir +'/recruitLaunched.json' ):
+        rc2 = subprocess.call( ['./plotLocustOutput.py', '--dataDirPath', outDataDir],
+            stdout=subprocess.DEVNULL )
+        if rc2:
+            logger.warning( 'plotLocustOutput.py exited with returnCode %d', rc2 )
 
     sys.exit( rc )
 except KeyboardInterrupt:
